@@ -116,7 +116,7 @@ int main() {
       AlwaysAssert(max(a,b) == b, AipsError);
     }
   }
-  catch (AipsError x) {
+  catch (AipsError& x) {
     cerr << x.getMesg() << endl;
     cout << "FAIL" << endl;
     return 1;
