@@ -28,6 +28,10 @@
 #ifndef CASA_STACKERROR_H
 #define CASA_STACKERROR_H
 
+#ifndef AIPS_USE_DEPRECATED
+#error "StackError.h is deprecated; use -DBUILD_DEPRECATED=ON to use it"
+#endif
+
 //# Includes
 #include <casacore/casa/aips.h>
 #include <casacore/casa/Exceptions/Error.h>
