@@ -614,7 +614,7 @@ int mspace_mallopt(int, int);
 #endif  /* MSPACES */
 
 #ifdef __cplusplus
-};  /* end of extern "C" */
+}  /* end of extern "C" */
 #endif
 
 #endif /* MALLOC_280_H */
