@@ -685,7 +685,7 @@ int main()
     checkFloat (error);
     checkDouble (error);
   } 
-  catch (AipsError x) {
+  catch (AipsError& x) {
     cerr << x.getMesg() << endl;
     cout << "FAIL" << endl;
     return 1;
