@@ -78,10 +78,40 @@ void doit8 ();
 void doit9 ();
 void doit10 ();
 
+#if defined(USE_THREADS)
+#include <thread>
+
+void _create_many_coordinates()
+{
+	// Simply copying a coordinate originally caused multithreading problems
+    for(size_t i = 0; i != 1000; i++) {
+        DirectionCoordinate d1;
+        DirectionCoordinate d2(d1);
+    }
+}
+
+void test_multithreaded_behaviour()
+{
+	std::cout << "*** Test multithreaded coordinate creation" << std::endl;
+	auto t1 = std::thread(_create_many_coordinates);
+	auto t2 = std::thread(_create_many_coordinates);
+	t1.join();
+	t2.join();
+}
+#endif // USE_THREADS
+
+
 
 
 int main()
 {
+
+#if defined(USE_THREADS)
+    {
+        test_multithreaded_behaviour();
+    }
+#endif // USE_THREADS
+
    try {
 
       Projection proj;
@@ -161,7 +191,7 @@ int main()
                                 xform, crpix(0), crpix(1), longPole, latPole);
 //
         if (!dc1.near(dc2)) {
-           throw(AipsError(String("Quantum interface constructor failed consistency test")));
+           throw(AipsError("Quantum interface constructor failed consistency test"));
         }
       }
 
@@ -403,6 +433,113 @@ int main()
     	  cout << "*** b " << worldb << endl;
     	  //cout << "*** c " << worldc << endl;
     	  cout << "*** inc " << converted.increment() << endl;
+
+    	  std::map<std::pair<Int, Int>, Double> expAngle;
+    	  expAngle[std::pair<Int, Int>(0, -80)] = -165.668663;
+    	  expAngle[std::pair<Int, Int>(0, -60)] = -159.272545;
+    	  expAngle[std::pair<Int, Int>(0, -40)] = -136.458146;
+    	  expAngle[std::pair<Int, Int>(0, -20)] = -56.3749304;
+    	  expAngle[std::pair<Int, Int>(0, 0)] = -23.4795798;
+    	  expAngle[std::pair<Int, Int>(0, 20)] = -15.2757315;
+    	  expAngle[std::pair<Int, Int>(0, 40)] = -12.3186824;
+    	  expAngle[std::pair<Int, Int>(0, 60)] = -11.4331534;
+    	  expAngle[std::pair<Int, Int>(0, 80)] = -11.9775365;
+    	  expAngle[std::pair<Int, Int>(4, -80)] = 128.395658;
+    	  expAngle[std::pair<Int, Int>(4, -60)] = 114.424745;
+    	  expAngle[std::pair<Int, Int>(4, -40)] = 93.4929423;
+    	  expAngle[std::pair<Int, Int>(4, -20)] = 71.2514923;
+    	  expAngle[std::pair<Int, Int>(4, 0)] = 55.048387;
+    	  expAngle[std::pair<Int, Int>(4, 20)] = 45.7495975;
+    	  expAngle[std::pair<Int, Int>(4, 40)] = 41.4598396;
+    	  expAngle[std::pair<Int, Int>(4, 60)] = 40.9329567;
+    	  expAngle[std::pair<Int, Int>(4, 80)] = 44.0088699;
+    	  expAngle[std::pair<Int, Int>(8, -80)] = 68.355075;
+    	  expAngle[std::pair<Int, Int>(8, -60)] = 61.8452755;
+    	  expAngle[std::pair<Int, Int>(8, -40)] = 58.6597989;
+    	  expAngle[std::pair<Int, Int>(8, -20)] = 58.6455176;
+    	  expAngle[std::pair<Int, Int>(8, 0)] = 61.8014664;
+    	  expAngle[std::pair<Int, Int>(8, 20)] = 68.2804866;
+    	  expAngle[std::pair<Int, Int>(8, 40)] = 78.0043392;
+    	  expAngle[std::pair<Int, Int>(8, 60)] = 89.9436203;
+    	  expAngle[std::pair<Int, Int>(8, 80)] = 101.89424;
+    	  expAngle[std::pair<Int, Int>(12, -80)] = 11.9775367;
+    	  expAngle[std::pair<Int, Int>(12, -60)] = 11.4331535;
+    	  expAngle[std::pair<Int, Int>(12, -40)] = 12.3186824;
+    	  expAngle[std::pair<Int, Int>(12, -20)] = 15.2757315;
+    	  expAngle[std::pair<Int, Int>(12, 0)] = 23.4795796;
+    	  expAngle[std::pair<Int, Int>(12, 20)] = 56.3749301;
+    	  expAngle[std::pair<Int, Int>(12, 40)] = 136.458146;
+    	  expAngle[std::pair<Int, Int>(12, 60)] = 159.272545;
+    	  expAngle[std::pair<Int, Int>(12, 80)] = 165.668663;
+    	  expAngle[std::pair<Int, Int>(16, -80)] = -44.0088701;
+    	  expAngle[std::pair<Int, Int>(16, -60)] = -40.9329566;
+    	  expAngle[std::pair<Int, Int>(16, -40)] = -41.4598395;
+    	  expAngle[std::pair<Int, Int>(16, -20)] = -45.7495973;
+    	  expAngle[std::pair<Int, Int>(16, 0)] = -55.0483868;
+    	  expAngle[std::pair<Int, Int>(16, 20)] = -71.2514922;
+    	  expAngle[std::pair<Int, Int>(16, 40)] = -93.4929422;
+    	  expAngle[std::pair<Int, Int>(16, 60)] = -114.424745;
+    	  expAngle[std::pair<Int, Int>(16, 80)] = -128.395658;
+    	  expAngle[std::pair<Int, Int>(20, -80)] = -101.894241;
+    	  expAngle[std::pair<Int, Int>(20, -60)] = -89.9436205;
+    	  expAngle[std::pair<Int, Int>(20, -40)] = -78.0043394;
+    	  expAngle[std::pair<Int, Int>(20, -20)] = -68.2804869;
+    	  expAngle[std::pair<Int, Int>(20, 0)] = -61.8014666;
+    	  expAngle[std::pair<Int, Int>(20, 20)] = -58.6455178;
+    	  expAngle[std::pair<Int, Int>(20, 40)] = -58.659799;
+    	  expAngle[std::pair<Int, Int>(20, 60)] = -61.8452755;
+    	  expAngle[std::pair<Int, Int>(20, 80)] = -68.3550746;
+    	  // test various points around the sky
+    	  for (Int ha=0; ha<24; ha+=4) {
+    	      for (Int dec=-80; dec<85; dec+=20) {
+    	          DirectionCoordinate j2000(
+    	              MDirection::J2000, p, Quantity(ha*15, "deg"),
+    	              Quantity(dec, "deg"), Quantity(-1, "arcsec"),
+    	              Quantity(1, "arcsec"), xform, 100, 100
+    	          );
+    	          units = j2000.worldAxisUnits();
+    	          Vector<Double> j2000RefVal = j2000.referenceValue();
+    	          MDirection j2000RefDir(
+    	              Quantity(j2000RefVal[0], units[0]),
+    	              Quantity(j2000RefVal[1], units[1]),
+    	              MDirection::J2000
+    	          );
+    	          DirectionCoordinate toGalactic = j2000.convert(
+    	              angle, MDirection::GALACTIC
+    	          );
+    	          AlwaysAssert(
+    	              allEQ(toGalactic.worldAxisUnits(), units), AipsError
+    	          );
+    	          AlwaysAssert(
+    	              allEQ(toGalactic.linearTransform(), xform), AipsError
+    	          );
+    	          AlwaysAssert(
+    	              toGalactic.projection().type() == p.type(), AipsError
+    	          );
+    	          AlwaysAssert(
+    	              near(
+    	                  angle.getValue("deg"),
+    	                  expAngle[std::pair<Int, Int>(ha, dec)], 1e-7
+    	              ), AipsError
+    	          );
+    	          DirectionCoordinate backToJ2000 = toGalactic.convert(
+    	              angle, MDirection::J2000
+    	          );
+    	          Vector<Double> newJ2000RefVal = backToJ2000.referenceValue();
+    	          if (newJ2000RefVal[0] < -0.1) {
+    	              newJ2000RefVal[0] += 2*C::pi;
+    	          }
+    	          AlwaysAssert(
+    	              allNearAbs(newJ2000RefVal, j2000RefVal, 1e-9), AipsError
+    	          );
+    	          AlwaysAssert(
+    	              near(
+    	                  angle.getValue("deg"),
+    	                  -expAngle[std::pair<Int, Int>(ha, dec)], 1e-7
+    	              ), AipsError
+    	          );
+    	      }
+    	  }
       }
       {
     	  cout << "*** test hasSquarePixels()" << endl;
