@@ -477,7 +477,7 @@ int main()
       }
 
        
-   } catch (AipsError x) {
+   } catch (AipsError& x) {
       cerr << "aipserror: error " << x.getMesg() << endl;
       return (1);
    }
