@@ -397,7 +397,7 @@ namespace casacore {
       throw AipsError("POLARIZATION subtable of " + table.tableName() +
                       " is empty");
     }
-    Vector<Int> inTypes (ROArrayColumn<Int>(polTable, "CORR_TYPE")(0));
+    Vector<Int> inTypes (ArrayColumn<Int>(polTable, "CORR_TYPE")(0));
     // Convert the output string types to ints.
     // First convert abbrevs.
     if (type == "IQUV"  ||  type == "STOKES") {
@@ -455,9 +455,8 @@ namespace casacore {
         Vector<Int> selectedAnts1;
         Vector<Int> selectedAnts2;
         Matrix<Int> selectedBaselines;
-        MSSelectionErrorHandler* curHandler = MSAntennaParse::thisMSAErrorHandler;
-        UDFMSCalErrorHandler errorHandler;
-        MSAntennaParse::thisMSAErrorHandler = &errorHandler;
+        CountedPtr<MSSelectionErrorHandler> curHandler = MSAntennaParse::thisMSAErrorHandler;
+        MSAntennaParse::thisMSAErrorHandler = new UDFMSCalErrorHandler();
         try {
           itsDataNode = msAntennaGramParseCommand (anttab, a1, a2, selStr, 
                                                    selectedAnts1, selectedAnts2,
@@ -538,9 +537,8 @@ namespace casacore {
         Vector<Int> selectedFeed1;
         Vector<Int> selectedFeed2;
         Matrix<Int> selectedFeedPairs;
-        MSSelectionErrorHandler* curHandler = MSFeedParse::thisMSFErrorHandler;
-        UDFMSCalErrorHandler errorHandler;
-        MSFeedParse::thisMSFErrorHandler = &errorHandler;
+        CountedPtr<MSSelectionErrorHandler> curHandler = MSFeedParse::thisMSFErrorHandler;
+        MSFeedParse::thisMSFErrorHandler = new UDFMSCalErrorHandler();
         try {
           itsDataNode = msFeedGramParseCommand (feedtab, f1, f2, selStr, 
                                                 selectedFeed1, selectedFeed2,
@@ -572,9 +570,8 @@ namespace casacore {
       {
         MeasurementSet ms(table);
         Vector<Int> stateid;
-        MSSelectionErrorHandler* curHandler = MSStateParse::thisMSSErrorHandler;
-        UDFMSCalErrorHandler errorHandler;
-        MSStateParse::thisMSSErrorHandler = &errorHandler;
+        CountedPtr<MSSelectionErrorHandler> curHandler = MSStateParse::thisMSSErrorHandler;
+        MSStateParse::thisMSSErrorHandler = new UDFMSCalErrorHandler();
         try {
           if (msStateGramParseCommand(&ms, selStr, stateid) == 0) {
             itsDataNode = *(msStateGramParseNode());
