@@ -46,8 +46,13 @@ ImageBeamSet::ImageBeamSet() :
     _maxBeam    (GaussianBeam::NULL_BEAM),
     _minBeamPos (2, 0), _maxBeamPos(2, 0) {}
 
-ImageBeamSet::ImageBeamSet(const Matrix<GaussianBeam>& beams) :
-    _beams(beams) {
+ImageBeamSet::ImageBeamSet(const Matrix<GaussianBeam>& beams) 
+: _beams(beams) {
+    ThrowIf(
+        beams.empty(),
+        "The number of channels and/or the number of stokes in "
+        "the beams matrix is zero, which is not permitted"
+    );
     _calculateAreas();
 }
 
@@ -198,69 +203,52 @@ void ImageBeamSet::setBeam(Int chan, Int stokes, const GaussianBeam& beam) {
         Int(chan) < _beams.shape()[0] && Int(stokes) < _beams.shape()[1],
         AipsError
     );
-    if (chan >= 0 && stokes >= 0) {
-        _beams(chan, stokes) = beam;
-        IPosition location(2, chan, stokes);
-        if (location == _maxBeamPos || location == _minBeamPos) {
-            // we are overwriting the max or min beam, so we need to
-            // determine the new max or min
-            _calculateAreas();
-        }
-        else {
-            Double area = beam.getArea(_areaUnit);
-            _areas(chan, stokes) = area;
-            if (area < _areas(_minBeamPos)) {
-                _minBeam = beam;
-                _minBeamPos = location;
-            }
-            if (area > _areas(_maxBeamPos)) {
-                _maxBeam = beam;
-                _maxBeamPos = location;
-            }
-        }
-    }
-    else if (chan < 0 && stokes < 0) {
+    if (chan < 0 && stokes < 0) {
         *this = ImageBeamSet(beam);
     }
+    else if (chan >= 0 && stokes >= 0) {
+        IPosition location(2, chan, stokes);
+        _replaceBeam(
+            beam, location, location,
+            _maxBeamPos == location || _minBeamPos[1] == location
+        );
+    }
     else if (chan < 0) {
-        _beams(IPosition(2, 0, stokes), IPosition(2, nchan()-1, stokes)) = beam;
-        if (_maxBeamPos[0] == chan || _minBeamPos[0] == chan) {
-            // we are overwriting the max or min beam, so we need to recalculate
-            // the areas
-            _calculateAreas();
-        }
-        else {
-            Double area = beam.getArea(_areaUnit);
-            _areas(IPosition(2, 0, stokes), IPosition(2, nchan()-1, stokes)) = area;
-            if (area < _areas(_minBeamPos)) {
-                _minBeam = beam;
-                _minBeamPos = IPosition(2, 0, stokes);
-            }
-            if (area > _areas(_maxBeamPos)) {
-                _maxBeam = beam;
-                _maxBeamPos = IPosition(2, 0, stokes);
-            }
-        }
+        // && stokes >= 0
+        _replaceBeam(
+            beam, IPosition(2, 0, stokes), IPosition(2, nchan()-1, stokes),
+            _maxBeamPos[1] == stokes || _minBeamPos[1] == stokes
+        );
     }
     else {
         // chan >=0 && stokes < 0
-        _beams(IPosition(2, chan, 0), IPosition(2, chan, nstokes()-1)) = beam;
-        if (_maxBeamPos[1] == stokes || _minBeamPos[1] == stokes) {
-            // we are overwriting the max or min beam, so we need to recalculate
-            // the areas
-            _calculateAreas();
+        _replaceBeam(
+            beam, IPosition(2, chan, 0), IPosition(2, chan, nstokes()-1),
+            _maxBeamPos[0] == chan || _minBeamPos[0] == chan
+        );
+    }
+}
+
+void ImageBeamSet::_replaceBeam(
+    const GaussianBeam& beam, const IPosition& location1,
+    const IPosition& location2, Bool overwriteMaxMin
+) {
+    _beams(location1, location2) = beam;
+    if (overwriteMaxMin) {
+        // we are overwriting the max or min beam, so we need to recalculate
+        // the areas
+        _calculateAreas();
+    }
+    else {
+        const auto area = beam.getArea(_areaUnit);
+        _areas(location1, location2) = area;
+        if (area < _areas(_minBeamPos)) {
+            _minBeam = beam;
+            _minBeamPos = location1;
         }
-        else {
-            Double area = beam.getArea(_areaUnit);
-            _areas(IPosition(2, chan, 0), IPosition(2, chan, nstokes()-1)) = area;
-            if (area < _areas(_minBeamPos)) {
-                _minBeam = beam;
-                _minBeamPos = IPosition(2, chan, 0);
-            }
-            if (area > _areas(_maxBeamPos)) {
-                _maxBeam = beam;
-                _maxBeamPos = IPosition(2, chan, 0);
-            }
+        if (area > _areas(_maxBeamPos)) {
+            _maxBeam = beam;
+            _maxBeamPos = location1;
         }
     }
 }
@@ -371,7 +359,7 @@ const GaussianBeam ImageBeamSet::getSmallestMinorAxisBeam() const {
 }
 
 void ImageBeamSet::_calculateAreas() {
-    _areas.resize(_beams.shape());
+     _areas.resize(_beams.shape());
     if (!_beams.empty()) {
         _areaUnit = _beams.begin()->getMajor().getUnit();
         _areaUnit =
@@ -463,31 +451,36 @@ ImageBeamSet ImageBeamSet::fromRecord(const Record& rec) {
         ! rec.isDefined("nStokes"),
         "no nStokes field found"
     );
-    uInt nchan = rec.asuInt("nChannels");
-    ImageBeamSet beams(nchan, rec.asuInt("nStokes"));
+    auto nchan = rec.asuInt("nChannels");
+    if (nchan == 0) {
+        // provide backward compatibility for records written with 0 channels
+        nchan = 1;
+    }
+    auto nstokes = rec.asuInt("nStokes");
+    if (nstokes == 0) {
+        // provide backward compatibility for records written with 0 stokes
+        nstokes = 1;
+    }
     uInt count = 0;
     uInt chan = 0;
     uInt stokes = 0;
-    Array<GaussianBeam>::const_iterator iterend = beams.getBeams().end();
+    Matrix<GaussianBeam> beams(nchan, nstokes);
+    auto iterend = beams.end();
     for (
-        Array<GaussianBeam>::const_iterator iter =
-        beams.getBeams().begin(); iter != iterend; ++iter, ++count
+        auto iter = beams.begin(); iter != iterend; ++iter, ++count
     ) {
         String field = "*" + String::toString(count);
         ThrowIf(
             ! rec.isDefined(field),
             "Field " + field + " is not defined"
         );
-        beams.setBeam(
-            chan, stokes,
-            GaussianBeam::fromRecord(rec.asRecord(field))
-        );
+            *iter = GaussianBeam::fromRecord(rec.asRecord(field));
         if (++chan == nchan) {
             chan = 0;
-            stokes++;
+            ++stokes;
         }
     }
-    return beams;
+    return ImageBeamSet(beams);
 }
 
 Record ImageBeamSet::toRecord() const {
