@@ -31,7 +31,6 @@
 #include <casacore/casa/BasicSL/String.h>
 #include <casacore/casa/Containers/Record.h>
 #include <casacore/casa/Containers/Block.h>
-#include <casacore/casa/Containers/HashMap.h>
 #include <casacore/casa/Exceptions/Error.h>
 #include <casacore/casa/Logging/LogIO.h>
 #include <casacore/casa/Logging/LogFilter.h>
@@ -68,10 +67,9 @@
 namespace casacore { //# name space casa begins
 
 
-  RegionManager::RegionManager()
+  RegionManager::RegionManager() : itsCSys(nullptr)
   {
       itsLog= new LogIO();
-      itsCSys=0;
   }
 
   RegionManager::RegionManager(const CoordinateSystem& csys) : itsCSys(new CoordinateSystem(csys))
@@ -84,9 +82,6 @@ namespace casacore { //# name space casa begins
   {
     if(itsLog !=0)
       delete itsLog;
-    if(itsCSys != 0)
-      delete itsCSys;
-
   }
 
   /*************************************************************
@@ -112,11 +107,11 @@ namespace casacore { //# name space casa begins
   }
 
   void RegionManager::setcoordsys(const CoordinateSystem& csys){
-    itsCSys= new CoordinateSystem(csys);
+    itsCSys.reset( new CoordinateSystem(csys) );
   }
 
   const CoordinateSystem& RegionManager::getcoordsys() const{
-	  if (itsCSys == 0) {
+	  if (!itsCSys) {
 	      throw(AipsError("CoordinateSystem not set in RegionManager tool"));
 	  }
 	  return *itsCSys;
@@ -210,7 +205,7 @@ namespace casacore { //# name space casa begins
 			      const Vector<Int>& pixelaxes,  
 			      const String& absrel, const String& comment){
  
-    if(itsCSys==0) {
+    if(!itsCSys) {
       ThrowCc("CoordinateSystem has not been set");
     }
     ImageRegion * leImReg=wbox(blc, trc, pixelaxes, *itsCSys, absrel);
@@ -365,7 +360,7 @@ namespace casacore { //# name space casa begins
 				       const Vector<Int>& pixelaxes,  
 				       const String& absrel){
     *itsLog << LogOrigin("RegionManager", "wpolygon");
-    if(itsCSys !=0){
+    if(itsCSys){
       return wpolygon(x, y, pixelaxes, *itsCSys, absrel);
     }
     else{
@@ -403,7 +398,7 @@ namespace casacore { //# name space casa begins
 		  const String& absrel
   ) const {
 	  *itsLog << LogOrigin("RegionManager", __FUNCTION__);
-	  if (itsCSys == 0) {
+	  if (!itsCSys) {
 		  throw(AipsError("CoordinateSystem not set in RegionManager tool"));
 	  }
 	  return wellipse(xc, yc, a, b, pa, pixelAxis0, pixelAxis1, *itsCSys, absrel);
@@ -429,7 +424,7 @@ namespace casacore { //# name space casa begins
 		  const String& absrel
   ) const {
 	  *itsLog << LogOrigin("RegionManager", __FUNCTION__);
-	  if(itsCSys == 0){
+	  if(!itsCSys){
 		  throw(AipsError("CoordinateSystem not set in RegionManager tool"));
 	  }
 	  return wsphere(center, radius, pixelAxes, *itsCSys, absrel);
@@ -454,7 +449,7 @@ namespace casacore { //# name space casa begins
 		  const String& absrel
   ) const {
 	  *itsLog << LogOrigin("RegionManager", __FUNCTION__);
-	  if(itsCSys == 0){
+	  if(!itsCSys){
 		  throw(AipsError("CoordinateSystem not set in RegionManager tool"));
 	  }
 	  return wellipsoid(center, radii, pixelAxes, *itsCSys, absrel);
@@ -498,7 +493,7 @@ namespace casacore { //# name space casa begins
 		  const String& absrel
   ) const {
 	  *itsLog << LogOrigin("RegionManager", __FUNCTION__);
-	  if(itsCSys == 0){
+	  if(!itsCSys){
 		  throw(AipsError("CoordinateSystem not set in RegionManager tool"));
 	  }
 	  return wshell(center, innerRadii, outerRadii, pixelAxes, *itsCSys, absrel);
@@ -814,7 +809,7 @@ namespace casacore { //# name space casa begins
 	myimage.defineRegion (newName, mask, RegionHandler::Masks);
 	retval=myimage.hasRegion(newName);
       }
-      catch(AipsError x){
+      catch(AipsError& x){
 	throw(AipsError("Could not write mask in image "+tabName+" because "+x.getMesg()));
       }
       catch(...){
