@@ -647,7 +647,7 @@ Fit2D::ErrorTypes Fit2D::fitData(const Vector<Double>& values,
 // A valid solution includes non-convergence
 //
       itsValidSolution = True;
-   } catch (AipsError x) {
+   } catch (AipsError& x) {
       itsErrorMessage = String("Fitting failed because ") + x.getMesg();
       status = Fit2D::FAILED;
    } 
