@@ -624,7 +624,7 @@ int main (int argc, const char* argv[])
 	doIt (argc,argv);
 	cout<< "OK"<< endl;
 	return 0;
-    } catch (AipsError x) {
+    } catch (AipsError& x) {
 	cerr << "Caught exception: " << x.getMesg() << endl;
 	return 1;
     } 
