@@ -324,7 +324,7 @@ int main()
     Bool caught = False;
     try {
       al6ROIter.matrixCursor();
-    } catch (AipsError x) {
+    } catch (AipsError& x) {
       caught = True;
     } 
     AlwaysAssert(caught, AipsError);
@@ -332,7 +332,7 @@ int main()
     caught = False;
     try {
       al6ROIter.cubeCursor();
-    } catch (AipsError x) {
+    } catch (AipsError& x) {
       caught = True;
     } 
     AlwaysAssert(caught, AipsError);
@@ -378,7 +378,7 @@ int main()
     caught = False;
     try {
       al6Iter.vectorCursor();
-    } catch (AipsError x) {
+    } catch (AipsError& x) {
       caught = True;
     } 
     AlwaysAssert(caught, AipsError);
@@ -386,7 +386,7 @@ int main()
     caught = False;
     try {
       al6Iter.cubeCursor();
-    } catch (AipsError x) {
+    } catch (AipsError& x) {
       caught = True;
     } 
     AlwaysAssert(caught, AipsError);
@@ -885,7 +885,7 @@ int main()
       AlwaysAssertExit (to.asArray()(IPosition(4,0,0,0,1)) == 960);
       AlwaysAssertExit (allEQ(arr, to.asArray()));
     }
-  } catch (AipsError x) {
+  } catch (AipsError& x) {
     cerr << x.getMesg () << endl;
     cout << "FAIL" << endl; 
     return 1;
