@@ -639,7 +639,7 @@ int main() {
          try {
             lc.pixelMask();
             ok = False;
-         } catch (AipsError x) {
+         } catch (AipsError& x) {
             ok = True;
          } 
          if (!ok) {
@@ -728,7 +728,7 @@ int main() {
          try {
             lc.setLattice(ml1);
             ok = False;
-         } catch (AipsError x) {
+         } catch (AipsError&x) {
          } 
          if (!ok) {
             throw (AipsError("setLattice forced failure did not work - this was unexpected"));  
@@ -740,13 +740,13 @@ int main() {
             SubLattice<Float> ml4(l4, True);
             lc.setLattice(ml4);
             ok = False;
-         } catch (AipsError x) {;} 
+         } catch (AipsError& x) {;} 
          if (!ok) {
             throw (AipsError("setLattice forced failure did not work - this was unexpected"));  
          }
       }
 
-  } catch(AipsError x) {
+  } catch(AipsError& x) {
     cerr << x.getMesg() << endl;
     return 1;
   } 
