@@ -64,7 +64,7 @@ void testVectorROIter (const Lattice<Int>& lattice, Bool useRef)
         Matrix<Int> temp(iter.matrixCursor());
         throw(AipsError("tLatticeIterator - "
                         "matrixCursor worked where it should not have"));
-    } catch (AipsError x) {
+    } catch (AipsError& x) {
         if (!x.getMesg().contains("two non-degenerate")) {
 	    throw (AipsError (x.getMesg()));
         }
@@ -73,7 +73,7 @@ void testVectorROIter (const Lattice<Int>& lattice, Bool useRef)
         Cube<Int> temp(iter.cubeCursor());
         throw(AipsError("tLatticeIterator - "
                         "cubeCursor worked where it should not have"));
-    } catch (AipsError x) {
+    } catch (AipsError& x) {
         if (!x.getMesg().contains("three non-degenerate")) {
 	    throw (AipsError (x.getMesg()));
         }
@@ -128,7 +128,7 @@ void testMatrixROIter (const Lattice<Int>& lattice, Bool useRef)
         Vector<Int> temp(iter.vectorCursor());
         throw(AipsError("tLatticeIterator - "
                         "vectorCursor worked where it should not have"));
-    } catch (AipsError x) {
+    } catch (AipsError& x) {
         if (!x.getMesg().contains("one non-degenerate")) {
 	    throw (AipsError (x.getMesg()));
         }
@@ -137,7 +137,7 @@ void testMatrixROIter (const Lattice<Int>& lattice, Bool useRef)
         Cube<Int> temp(iter.cubeCursor());
         throw(AipsError("tLatticeIterator - "
                         "cubeCursor worked where it should not have"));
-    } catch (AipsError x) {
+    } catch (AipsError& x) {
         if (!x.getMesg().contains("three non-degenerate")) {
 	    throw (AipsError (x.getMesg()));
         }
@@ -193,7 +193,7 @@ void testCubeROIter (const Lattice<Int>& lattice, Bool useRef)
         Vector<Int> temp(iter.vectorCursor());
         throw(AipsError("tLatticeIterator - "
                         "vectorCursor worked where it should not have"));
-    } catch (AipsError x) {
+    } catch (AipsError& x) {
         if (!x.getMesg().contains("one non-degenerate")) {
 	    throw (AipsError (x.getMesg()));
         }
@@ -202,7 +202,7 @@ void testCubeROIter (const Lattice<Int>& lattice, Bool useRef)
         Matrix<Int> temp(iter.matrixCursor());
         throw(AipsError("tLatticeIterator - "
                         "matrixCursor worked where it should not have"));
-    } catch (AipsError x) {
+    } catch (AipsError& x) {
         if (!x.getMesg().contains("two non-degenerate")) {
 	    throw (AipsError (x.getMesg()));
         }
@@ -252,7 +252,7 @@ void testArrayROIter (const Lattice<Int>& lattice, Bool useRef)
         Vector<Int> temp(iter.vectorCursor());
         throw(AipsError("tLatticeIterator - "
                         "vectorCursor worked where it should not have"));
-    } catch (AipsError x) {
+    } catch (AipsError& x) {
         if (!x.getMesg().contains("one non-degenerate")) {
 	    throw (AipsError (x.getMesg()));
         }
@@ -261,7 +261,7 @@ void testArrayROIter (const Lattice<Int>& lattice, Bool useRef)
         Matrix<Int> temp(iter.matrixCursor());
         throw(AipsError("tLatticeIterator - "
                         "matrixCursor worked where it should not have"));
-    } catch (AipsError x) {
+    } catch (AipsError& x) {
         if (!x.getMesg().contains("two non-degenerate")) {
 	    throw (AipsError (x.getMesg()));
         }
@@ -270,7 +270,7 @@ void testArrayROIter (const Lattice<Int>& lattice, Bool useRef)
         Cube<Int> temp(iter.cubeCursor());
         throw(AipsError("tLatticeIterator - "
                         "cubeCursor worked where it should not have"));
-    } catch (AipsError x) {
+    } catch (AipsError& x) {
         if (!x.getMesg().contains("three non-degenerate")) {
 	    throw (AipsError (x.getMesg()));
         }
@@ -320,7 +320,7 @@ void test8ElemROIter (const Lattice<Int>& lattice, Bool useRef)
         Matrix<Int> temp(iter.matrixCursor());
         throw(AipsError("tLatticeIterator - "
                         "matrixCursor worked where it should not have"));
-    } catch (AipsError x) {
+    } catch (AipsError& x) {
         if (!x.getMesg().contains("two non-degenerate")) {
 	    throw (AipsError (x.getMesg()));
         }
@@ -329,7 +329,7 @@ void test8ElemROIter (const Lattice<Int>& lattice, Bool useRef)
         Cube<Int> temp(iter.cubeCursor());
         throw(AipsError("tLatticeIterator - "
                         "cubeCursor worked where it should not have"));
-    } catch (AipsError x) {
+    } catch (AipsError& x) {
         if (!x.getMesg().contains("three non-degenerate")) {
 	    throw (AipsError (x.getMesg()));
         }
@@ -624,7 +624,7 @@ void testVectorRWIter (Lattice<Int>& lattice, Bool useRef)
         Matrix<Int> temp(iter.matrixCursor());
         throw(AipsError("tLatticeIterator - "
                         "matrixCursor worked where it should not have"));
-    } catch (AipsError x) {
+    } catch (AipsError& x) {
         if (!x.getMesg().contains("two non-degenerate")) {
 	    throw (AipsError (x.getMesg()));
         }
@@ -633,7 +633,7 @@ void testVectorRWIter (Lattice<Int>& lattice, Bool useRef)
         Cube<Int> temp(iter.cubeCursor());
         throw(AipsError("tLatticeIterator - "
                         "cubeCursor worked where it should not have"));
-    } catch (AipsError x) {
+    } catch (AipsError& x) {
         if (!x.getMesg().contains("three non-degenerate")) {
 	    throw (AipsError (x.getMesg()));
         }
@@ -692,7 +692,7 @@ void testMatrixRWIter (Lattice<Int>& lattice, Bool useRef)
         Vector<Int> temp(iter.vectorCursor());
         throw(AipsError("tLatticeIterator - "
                         "vectorCursor worked where it should not have"));
-    } catch (AipsError x) {
+    } catch (AipsError& x) {
         if (!x.getMesg().contains("one non-degenerate")) {
 	    throw (AipsError (x.getMesg()));
         }
@@ -701,7 +701,7 @@ void testMatrixRWIter (Lattice<Int>& lattice, Bool useRef)
         Cube<Int> temp(iter.cubeCursor());
         throw(AipsError("tLatticeIterator - "
                         "cubeCursor worked where it should not have"));
-    } catch (AipsError x) {
+    } catch (AipsError& x) {
         if (!x.getMesg().contains("three non-degenerate")) {
 	    throw (AipsError (x.getMesg()));
         }
@@ -757,7 +757,7 @@ void testCubeRWIter (Lattice<Int>& lattice, Bool useRef)
         Vector<Int> temp(iter.vectorCursor());
         throw(AipsError("tLatticeIterator - "
                         "vectorCursor worked where it should not have"));
-    } catch (AipsError x) {
+    } catch (AipsError& x) {
         if (!x.getMesg().contains("one non-degenerate")) {
 	    throw (AipsError (x.getMesg()));
         }
@@ -766,7 +766,7 @@ void testCubeRWIter (Lattice<Int>& lattice, Bool useRef)
         Matrix<Int> temp(iter.matrixCursor());
         throw(AipsError("tLatticeIterator - "
                         "matrixCursor worked where it should not have"));
-    } catch (AipsError x) {
+    } catch (AipsError& x) {
         if (!x.getMesg().contains("two non-degenerate")) {
 	    throw (AipsError (x.getMesg()));
         }
@@ -816,7 +816,7 @@ void testArrayRWIter (Lattice<Int>& lattice, Bool useRef)
         Vector<Int> temp(iter.vectorCursor());
         throw(AipsError("tLatticeIterator - "
                         "vectorCursor worked where it should not have"));
-    } catch (AipsError x) {
+    } catch (AipsError& x) {
         if (!x.getMesg().contains("one non-degenerate")) {
 	    throw (AipsError (x.getMesg()));
         }
@@ -825,7 +825,7 @@ void testArrayRWIter (Lattice<Int>& lattice, Bool useRef)
         Matrix<Int> temp(iter.matrixCursor());
         throw(AipsError("tLatticeIterator - "
                         "matrixCursor worked where it should not have"));
-    } catch (AipsError x) {
+    } catch (AipsError& x) {
         if (!x.getMesg().contains("two non-degenerate")) {
 	    throw (AipsError (x.getMesg()));
         }
@@ -834,7 +834,7 @@ void testArrayRWIter (Lattice<Int>& lattice, Bool useRef)
         Cube<Int> temp(iter.cubeCursor());
         throw(AipsError("tLatticeIterator - "
                         "cubeCursor worked where it should not have"));
-    } catch (AipsError x) {
+    } catch (AipsError& x) {
         if (!x.getMesg().contains("three non-degenerate")) {
 	    throw (AipsError (x.getMesg()));
         }
@@ -1271,7 +1271,7 @@ int main (int argc, const char* argv[])
       pagedArr.put (savarr);
       testNonCongruentRWIter (pagedArr, True);
     }
-  } catch (AipsError x) {
+  } catch (AipsError& x) {
     cerr << "Caught exception: " << x.getMesg() << endl;
     cout << "FAIL" << endl;
     return 1;
@@ -1441,7 +1441,7 @@ int main (int argc, const char* argv[])
       testAdd (latArr1, pagedArr2, True);
       AlwaysAssert (allEQ(latArr1.get(), 13*arr), AipsError);
     }      
-  } catch (AipsError x) {
+  } catch (AipsError& x) {
     cerr << "Caught exception: " << x.getMesg() << endl;
     cout << "FAIL" << endl;
     return 1;
