@@ -31,11 +31,8 @@
 //# Includes
 #include <casacore/casa/aips.h>
 #include <casacore/meas/MeasUDF/EpochEngine.h>
+#include <casacore/meas/MeasUDF/PositionEngine.h>
 #include <casacore/tables/TaQL/UDFBase.h>
-#include <casacore/tables/TaQL/ExprNode.h>
-#include <casacore/measures/Measures/MEpoch.h>
-#include <casacore/measures/Measures/MCEpoch.h>
-#include <casacore/measures/Measures/MeasConvert.h>
 
 namespace casacore {
 
