@@ -141,7 +141,7 @@ int main (int argc, const char* argv[])
       try {
 	// no such column
 	TableQuantumDesc taexcep(td, "SillyName");
-      } catch (AipsError x) {
+      } catch (AipsError& x) {
 	cout << "A no such column message should follow\n";
 	cout << x.getMesg() << endl;
       } 
@@ -149,7 +149,7 @@ int main (int argc, const char* argv[])
       try {
 	// variable unit's column doesn't exist.
 	TableQuantumDesc taexcep(td, "ScaQuantComplex", "SillyName");
-      } catch (AipsError x) {
+      } catch (AipsError& x) {
 	cout << "A no such unit's column message should follow\n";
 	cout << x.getMesg() << endl;
       } 
@@ -160,7 +160,7 @@ int main (int argc, const char* argv[])
 		  "variable units column with incorrect type");
 	td.addColumn(eucol);
 	TableQuantumDesc taexcep(td, "ScaQuantComplex", "testvarcolumn");
-      } catch (AipsError x) {
+      } catch (AipsError& x) {
 	cout << "A message about an incorrect variable unit's type...\n";
 	cout << x.getMesg() << endl;
       } 
@@ -223,7 +223,7 @@ int main (int argc, const char* argv[])
 	  // test isnull exception
 	  try {
 	    sqCol.throwIfNull();
-	  } catch (AipsError x) {
+	  } catch (AipsError& x) {
 	    cout << "Catch an AipsError. Column is null...\n";
 	    cout << x.getMesg() << endl;
 	  } 
@@ -365,7 +365,7 @@ int main (int argc, const char* argv[])
       if (doExcep) {
 	try {
 	  tmpCol.throwIfNull();
-	} catch (AipsError x) {
+	} catch (AipsError& x) {
 	  cout << "Catch an AipsError. Array column is null...\n";
 	  cout << x.getMesg() << endl;
 	} 
@@ -375,7 +375,7 @@ int main (int argc, const char* argv[])
 	  // create with a real column but not a quantum column
           // It will succeed because the QuantumDesc does not require a unit.
 	  ArrayQuantColumn<Double> testCol(qtab, "BogusQuantCol");
-	} catch (AipsError x) {
+	} catch (AipsError& x) {
 	  cout << "Exception should not occur" << endl;
 	} 
       }
@@ -408,7 +408,7 @@ int main (int argc, const char* argv[])
 	try {
 	  Array<Quantum<Double> > badShapeArr(IPosition(2,2));
 	  roaqCol.get(0, badShapeArr, False);
-	} catch (AipsError x) {
+	} catch (AipsError& x) {
 	  cout << "The following line should be a ";
 	  cout << "Table array conformance error exception.\n";
 	  cout << x.getMesg() << endl;
@@ -527,7 +527,7 @@ int main (int argc, const char* argv[])
         }
     }
 
-  } catch (AipsError x) {
+  } catch (AipsError& x) {
     cout << "Unexpected exception1: " << x.getMesg() << endl;
     return 1;
   } 
@@ -548,7 +548,7 @@ int main (int argc, const char* argv[])
     for (i=0; i<qtab.nrow(); i++) {
       cout << "Quantum " << i << ": " << rosqCol(i) << endl;
     }
-  } catch (AipsError x) {
+  } catch (AipsError& x) {
     cout << "Unexpected exception2: " << x.getMesg() << endl;
     return 1;
   } 
@@ -597,7 +597,7 @@ int main (int argc, const char* argv[])
     }
     timer.show ("get tab    arrays");
     cout << "<<<" << endl;
-  } catch (AipsError x) {
+  } catch (AipsError& x) {
     cout << "Unexpected exception3: " << x.getMesg() << endl;
     return 1;
   } 
