@@ -425,7 +425,7 @@ const tableProperties allProperties[] = {
     "TAI_UTC difference obtained from USNO",		"leapSecond",
     False,			"",			vector<String>(),
     0, 				vector<formatDescr>(),
-    { "maia.usno.navy.mil", "ser7", "tai-utc.dat" } },
+    { "ftp.astron.nl", "outgoing/Measures", "tai-utc.dat" } },
 
   //**********************************************************************//
 
@@ -461,7 +461,7 @@ const tableProperties allProperties[] = {
     "IERS Earth Orientation Data predicted from NEOS",	"predict",
     False,			"",			vector<String>(),
     &IERSpredictFormat,		vector<formatDescr>(),
-    { "maia.usno.navy.mil", "ser7", "finals.daily" } },
+    { "ftp.iers.org", "products/eop/rapid/daily", "finals.daily" } },
 
   //**********************************************************************//
 
@@ -473,7 +473,7 @@ const tableProperties allProperties[] = {
     "IERS EOP2000C04_05 Earth Orientation Data IAU2000","predict2000",
     False,			"",			vector<String>(),
     &IERSpredict2000Format,	vector<formatDescr>(),
-    { "maia.usno.navy.mil", "ser7", "finals2000A.daily" } },
+    { "ftp.iers.org", "products/eop/rapid/daily", "finals2000A.daily" } },
 
   //**********************************************************************//
 
@@ -485,7 +485,7 @@ const tableProperties allProperties[] = {
     "IGRF12 reference magnetic field",			"earthField",
     False,			"",			vector<String>(),
     &IGRFFormat,		vector<formatDescr>(),
-    { "www.ngdc.noaa.gov", "IAGA/vmod", "igrf12coeffs.txt" } },
+    { "www.ngdc.noaa.gov", "IAGA/vmod/coeffs", "igrf12coeffs.txt" } },
 
   //**********************************************************************//
 
@@ -853,7 +853,7 @@ Bool testu_table(const tableProperties &tprop, inputValues &inVal) {
 	inVal.forcedel = True;
 	inVal.noup = False;
       } else if (String(inVal.type, 0, 2) == String("DE")) {
-	uInt uyr = MVTime(inVal.lastmjd).year();
+	Int uyr = MVTime(inVal.lastmjd).year();
         if (uyr < inVal.derange[1]) {
 	  // this only guarantees there will be /some/ data from derange[1]
 	  // but it looks like the DE ascii files finish in December of
@@ -958,7 +958,7 @@ Int last_mjd(const Table *tab) {
   uInt n = tab->nrow();
   Double mjd;
   if (n<1) mjd = 0;
-  else ROScalarColumn<Double>(*tab, "MJD").get(n-1, mjd);
+  else ScalarColumn<Double>(*tab, "MJD").get(n-1, mjd);
   return Int(mjd); 
 }
 
@@ -1427,7 +1427,7 @@ Bool JPLDE(tableProperties &tprop, inputValues &inVal) {
   // Test if to update
   if (testu_table(tprop, inVal) && inVal.noup) return True;
  
-  uInt uyr; // value will be set from data file name
+  Int uyr = 0; // value will be set from data file name
   // Check if header present
   Path hpath(tprop.vinfo[0]);
   if (hpath.isValid() && File(hpath).exists() && File(hpath).isReadable()) {
@@ -1809,7 +1809,7 @@ int main (int argc, const char** argv) {
     // Create the full properties
     makeProperties();
 
-  } catch (AipsError x) {
+  } catch (AipsError& x) {
     cout << x.getMesg() << endl;
     exit(1);
   } 
@@ -1854,7 +1854,7 @@ int main (int argc, const char** argv) {
 // Finish
 //*************************************************************************//
 
-  } catch (AipsError x) {
+  } catch (AipsError& x) {
     cout << x.getMesg() << endl;
     exit(1);
   } 
