@@ -64,7 +64,7 @@
 #include <casacore/casa/Exceptions/Error.h>
 #include <casacore/casa/Utilities/GenSort.h>
 #include <casacore/ms/MeasurementSets/MSColumns.h>
-#include <casa/Utilities/CountedPtr.h>
+#include <casacore/casa/Utilities/CountedPtr.h>
 namespace casacore { //# NAMESPACE CASACORE - BEGIN
   
   //----------------------------------------------------------------------------
@@ -77,7 +77,6 @@ namespace casacore { //# NAMESPACE CASACORE - BEGIN
     fieldIDs_p(), spwIDs_p(), scanIDs_p(), arrayIDs_p(), ddIDs_p(), observationIDs_p(),
     feed1IDs_p(), feed2IDs_p(), baselineIDs_p(), feedPairIDs_p(),
     selectedTimesList_p(), selectedUVRange_p(),selectedUVUnits_p(),
-    selectedPolMap_p(Vector<Int>(0)), selectedSetupMap_p(Vector<Vector<Int> >(0)),
     maxScans_p(1000), maxObs_p(1000), maxArray_p(1000), 
     isMS_p(True), toTENCalled_p(False)
   {
@@ -112,7 +111,6 @@ namespace casacore { //# NAMESPACE CASACORE - BEGIN
     feedExpr_p(""), exprOrder_p(MAX_EXPR, NO_EXPR), antenna1IDs_p(), antenna2IDs_p(),
     fieldIDs_p(), spwIDs_p(), scanIDs_p(),ddIDs_p(),baselineIDs_p(), feedPairIDs_p(),
     selectedTimesList_p(), selectedUVRange_p(),selectedUVUnits_p(),
-    selectedPolMap_p(Vector<Int>(0)), selectedSetupMap_p(Vector<Vector<Int> >(0)),
     maxScans_p(1000), maxObs_p(1000), maxArray_p(1000), 
     isMS_p(True), toTENCalled_p(False)
   {
@@ -281,8 +279,7 @@ namespace casacore { //# NAMESPACE CASACORE - BEGIN
     timeExpr_p(""), uvDistExpr_p(""), polnExpr_p(""),taqlExpr_p(""),stateExpr_p(""), 
     observationExpr_p(""), feedExpr_p(""),
     antenna1IDs_p(), antenna2IDs_p(), fieldIDs_p(), spwIDs_p(), ddIDs_p(),
-    feed1IDs_p(), feed2IDs_p(), baselineIDs_p(), feedPairIDs_p(),
-    selectedPolMap_p(Vector<Int>(0)), selectedSetupMap_p(Vector<Vector<Int> >(0))
+    feed1IDs_p(), feed2IDs_p(), baselineIDs_p(), feedPairIDs_p()
     
   {
     // Construct from a record representing a selection item
@@ -304,10 +301,7 @@ namespace casacore { //# NAMESPACE CASACORE - BEGIN
   
   //----------------------------------------------------------------------------
   
-  MSSelection::MSSelection (const MSSelection& other):
-    selectedPolMap_p(Vector<Int>(0)),
-    selectedSetupMap_p(Vector<Vector<Int> >(0))
-    
+  MSSelection::MSSelection (const MSSelection& other)
   {
     // Copy constructor
     // Input:
@@ -486,8 +480,8 @@ namespace casacore { //# NAMESPACE CASACORE - BEGIN
   }
   //
   //----------------------------------------------------------------------------
-  // Method to install the defaul error hanlder or reset existing
-  // error handlers. If the pointer to error hanlder is NULL, this
+  // Method to install the defaul error handler or reset existing
+  // error handlers. If the pointer to error handler is NULL, this
   // method will install the default error handler.  If the pointer is
   // != NULL, this method will reset the existing error handler.
   //
@@ -503,10 +497,10 @@ namespace casacore { //# NAMESPACE CASACORE - BEGIN
       {
       case ANTENNA_EXPR:
 	{
-	  if (MSAntennaParse::thisMSAErrorHandler == NULL)
+	  if (MSAntennaParse::thisMSAErrorHandler.null())
 	    {
-	      MSSelectionErrorHandler* tt = new MSSelectionErrorHandler();
-	      setErrorHandler(ANTENNA_EXPR, tt, True);
+	      MSSelectionErrorHandler tt;
+	      setErrorHandler(ANTENNA_EXPR, &tt, True);
 	    }
 	  else
 	    MSAntennaParse::thisMSAErrorHandler->reset();
@@ -514,10 +508,10 @@ namespace casacore { //# NAMESPACE CASACORE - BEGIN
 	}
       case FEED_EXPR:
 	{
-	  if (MSFeedParse::thisMSFErrorHandler == NULL)
+	  if (MSFeedParse::thisMSFErrorHandler.null())
 	    {
-	      MSSelectionErrorHandler* tt = new MSSelectionErrorHandler();
-	      setErrorHandler(FEED_EXPR, tt, True);
+	      MSSelectionErrorHandler tt;
+	      setErrorHandler(FEED_EXPR, &tt, True);
 	    }
 	  else
 	    MSFeedParse::thisMSFErrorHandler->reset();
@@ -525,10 +519,10 @@ namespace casacore { //# NAMESPACE CASACORE - BEGIN
 	}
       case STATE_EXPR:
 	{
-	  if (MSStateParse::thisMSSErrorHandler == NULL)
+	  if (MSStateParse::thisMSSErrorHandler.null())
 	    {
-	      MSSelectionErrorHandler *tt = new MSSelectionErrorHandler();
-	      setErrorHandler(STATE_EXPR, tt, True);
+	      MSSelectionErrorHandler tt;
+	      setErrorHandler(STATE_EXPR, &tt, True);
 	    }
 	   else
 	     MSStateParse::thisMSSErrorHandler->reset();
@@ -536,10 +530,10 @@ namespace casacore { //# NAMESPACE CASACORE - BEGIN
 	}
       case SPW_EXPR:
 	{
-	  if (MSSpwParse::thisMSSpwErrorHandler == NULL)
+	  if (MSSpwParse::thisMSSpwErrorHandler.null())
 	    {
-	      MSSSpwErrorHandler* tt = new MSSSpwErrorHandler();
-	      setErrorHandler(SPW_EXPR, tt, True /*overRide*/);
+	      MSSSpwErrorHandler tt;
+	      setErrorHandler(SPW_EXPR, &tt, True /*overRide*/);
 	    }
 	  else
 	    MSSpwParse::thisMSSpwErrorHandler->reset();
@@ -803,7 +797,8 @@ namespace casacore { //# NAMESPACE CASACORE - BEGIN
   }
   
   //----------------------------------------------------------------------------
-  void MSSelection::setErrorHandler(const MSExprType type,  MSSelectionErrorHandler* mssEH,
+  void MSSelection::setErrorHandler(const MSExprType type,
+                                    MSSelectionErrorHandler* mssEH,
 				    const Bool overRide)
   {
     //
@@ -815,60 +810,46 @@ namespace casacore { //# NAMESPACE CASACORE - BEGIN
       {
       case ANTENNA_EXPR:
 	{
-	  if (overRide)
-	    {
-	      if (mssEH == NULL) MSAntennaParse::thisMSAErrorHandler = mssEH;
-	      else MSAntennaParse::thisMSAErrorHandler = mssEH->clone();
-	    }
-	  else if (MSAntennaParse::thisMSAErrorHandler == NULL)
-	    {
-	      if (mssEH == NULL) MSAntennaParse::thisMSAErrorHandler = mssEH;
-	      else MSAntennaParse::thisMSAErrorHandler = mssEH->clone();
+	  if (overRide  ||  MSAntennaParse::thisMSAErrorHandler.null()) {
+            if (mssEH == NULL) {
+              MSAntennaParse::thisMSAErrorHandler = mssEH;
+            } else {
+              MSAntennaParse::thisMSAErrorHandler = mssEH->clone();
 	    }
+          }
 	  break;
 	}
       case FEED_EXPR:
 	{
-	  if (overRide)
-	    {
-	      if (mssEH == NULL) MSFeedParse::thisMSFErrorHandler = mssEH;
-	      else MSFeedParse::thisMSFErrorHandler = mssEH->clone();
-	    }
-	  else if (MSFeedParse::thisMSFErrorHandler == NULL)
-	    {
-	      if (mssEH == NULL) MSFeedParse::thisMSFErrorHandler = mssEH;
-	      else MSFeedParse::thisMSFErrorHandler = mssEH->clone();
+	  if (overRide  ||  MSFeedParse::thisMSFErrorHandler.null()) {
+            if (mssEH == NULL) {
+              MSFeedParse::thisMSFErrorHandler = mssEH;
+            } else {
+              MSFeedParse::thisMSFErrorHandler = mssEH->clone();
 	    }
+          }
 	  break;
 	}
       case STATE_EXPR:
 	{
-	  if (overRide)
-	    {
-	      MSStateParse::cleanupErrorHandler();
-	      if (mssEH == NULL) MSStateParse::thisMSSErrorHandler = mssEH;
-	      else MSStateParse::thisMSSErrorHandler = mssEH->clone();
-	    }
-	  else if (MSStateParse::thisMSSErrorHandler == NULL)
-	    {
-	      if (mssEH == NULL) MSStateParse::thisMSSErrorHandler = mssEH;
-	      else MSStateParse::thisMSSErrorHandler = mssEH->clone();
+	  if (overRide  ||  MSStateParse::thisMSSErrorHandler.null()) {
+            if (mssEH == NULL) {
+              MSStateParse::thisMSSErrorHandler = mssEH;
+            } else {
+              MSStateParse::thisMSSErrorHandler = mssEH->clone();
 	    }
+          }
 	  break;
 	}
       case SPW_EXPR:
 	{
-	  if (overRide)
-	    {
-	      MSSpwParse::cleanupErrorHandler();
-	      if (mssEH == NULL) MSSpwParse::thisMSSpwErrorHandler = mssEH;
-	      else MSSpwParse::thisMSSpwErrorHandler = mssEH->clone();
-	    }
-	  else if (MSSpwParse::thisMSSpwErrorHandler == NULL)
-	    {
-	      if (mssEH == NULL) MSSpwParse::thisMSSpwErrorHandler = mssEH;
-	      else MSSpwParse::thisMSSpwErrorHandler = mssEH->clone();
+	  if (overRide  ||  MSSpwParse::thisMSSpwErrorHandler.null()) {
+            if (mssEH == NULL) {
+              MSSpwParse::thisMSSpwErrorHandler = mssEH;
+            } else {
+              MSSpwParse::thisMSSpwErrorHandler = mssEH->clone();
 	    }
+          }
 	  break;
 	}
       default: throw(MSSelectionError(String("Wrong MSExprType in MSSelection::setErrorHandler()")));
@@ -1360,7 +1341,7 @@ namespace casacore { //# NAMESPACE CASACORE - BEGIN
     
     if (chanList_l.shape()(0) == 0) return freqList_l;
 
-    const ROMSSpWindowColumns msSpwSubTable(ms_p->spectralWindow());
+    const MSSpWindowColumns msSpwSubTable(ms_p->spectralWindow());
     if (msSpwSubTable.nrow() <= (uInt)max(chanList_l.column(0)))
 	throw(MSSelectionError(String("MSS::getChanFreqList:: Internal error:  Selected list of SPW IDs > "
 				      "no. of rows in the SPECTRAL_WINDOW sub-table.")));
@@ -1426,13 +1407,12 @@ namespace casacore { //# NAMESPACE CASACORE - BEGIN
     corrslices.set(Vector<Slice>());
     
     // Get the corr indices as an ordered map
-    OrderedMap<Int, Vector<Vector<Int> > > corrmap(this->getCorrMap(ms));
+    std::map<Int, Vector<Vector<Int> > > corrmap(this->getCorrMap(ms));
     
     // Iterate over the ordered map to fill the slices
-    ConstMapIter<Int, Vector<Vector<Int> > > mi(corrmap);
-    for (mi.toStart(); !mi.atEnd(); mi++) {
-      Int pol=mi.getKey();
-      Vector<Int> corridx=mi.getVal()[0];
+    for (const auto& elem : corrmap) {
+      Int pol=elem.first;
+      Vector<Int> corridx=elem.second[0];
       
       Int ncorr=corridx.nelements();
       corrslices(pol).resize(ncorr);
