@@ -43,8 +43,7 @@ namespace casacore { //# NAMESPACE CASACORE - BEGIN
 MSWeather::MSWeather():hasBeenDestroyed_p(True) { }
 
 MSWeather::MSWeather(const String &tableName, TableOption option) 
-    : MSTable<PredefinedColumns,
-      PredefinedKeywords>(tableName, option),hasBeenDestroyed_p(False)
+    : MSTable<MSWeatherEnums>(tableName, option),hasBeenDestroyed_p(False)
 {
     // verify that the now opened table is valid
     if (! validate(this->tableDesc()))
@@ -54,8 +53,7 @@ MSWeather::MSWeather(const String &tableName, TableOption option)
 
 MSWeather::MSWeather(const String& tableName, const String &tableDescName,
 			       TableOption option)
-    : MSTable<PredefinedColumns,
-      PredefinedKeywords>(tableName, tableDescName,option),
+    : MSTable<MSWeatherEnums>(tableName, tableDescName,option),
       hasBeenDestroyed_p(False)
 {
     // verify that the now opened table is valid
@@ -66,8 +64,7 @@ MSWeather::MSWeather(const String& tableName, const String &tableDescName,
 
 MSWeather::MSWeather(SetupNewTable &newTab, uInt nrrow,
 			       Bool initialize)
-    : MSTable<PredefinedColumns,
-      PredefinedKeywords>(newTab, nrrow, initialize), 
+    : MSTable<MSWeatherEnums>(newTab, nrrow, initialize), 
       hasBeenDestroyed_p(False)
 {
     // verify that the now opened table is valid
@@ -77,8 +74,7 @@ MSWeather::MSWeather(SetupNewTable &newTab, uInt nrrow,
 }
 
 MSWeather::MSWeather(const Table &table)
-    : MSTable<PredefinedColumns,
-      PredefinedKeywords>(table), hasBeenDestroyed_p(False)
+    : MSTable<MSWeatherEnums>(table), hasBeenDestroyed_p(False)
 {
     // verify that the now opened table is valid
     if (! validate(this->tableDesc()))
@@ -87,8 +83,7 @@ MSWeather::MSWeather(const Table &table)
 }
 
 MSWeather::MSWeather(const MSWeather &other)
-    : MSTable<PredefinedColumns,
-      PredefinedKeywords>(other), 
+    : MSTable<MSWeatherEnums>(other), 
       hasBeenDestroyed_p(False)
 {
     // verify that other is valid
@@ -116,99 +111,96 @@ MSWeather::~MSWeather()
 MSWeather& MSWeather::operator=(const MSWeather &other)
 {
     if (&other != this) {
-	MSTable<PredefinedColumns,
-	PredefinedKeywords>::operator=(other);
+	MSTable<MSWeatherEnums>::operator=(other);
 	hasBeenDestroyed_p=other.hasBeenDestroyed_p;
     }
     return *this;
 }
 
-void MSWeather::init()
+MSTableMaps MSWeather::initMaps()
 {
-    if (! columnMap_p.ndefined()) {
-	// the PredefinedColumns
-	// ANTENNA_ID
-	colMapDef(ANTENNA_ID, "ANTENNA_ID", TpInt,
-		  "Antenna number","","");
-	// INTERVAL
-	colMapDef(INTERVAL, "INTERVAL", TpDouble,
-		  "Interval over which data is relevant","s","");
-	// TIME
-	colMapDef(TIME, "TIME", TpDouble,
-		  "An MEpoch specifying the midpoint of the time for"
-		  "which data is relevant","s","Epoch");
-	// DEW_POINT
-	colMapDef(DEW_POINT, "DEW_POINT", TpFloat,
-		  "Dew point","K","");
-	// DEW_POINT_FLAG
-	colMapDef(DEW_POINT_FLAG, "DEW_POINT_FLAG", TpBool,
-		  "Flag for dew point","","");
-	// H2O 
-	colMapDef(H2O, "H2O", TpFloat,
-		  "Average column density of water-vapor","m-2","");
-	// H2O_FLAG
-	colMapDef(H2O_FLAG, "H2O_FLAG", TpBool,
-		  "Flag for average column density of water-vapor","","");
-	// IONOS_ELECTRON
-	colMapDef(IONOS_ELECTRON, "IONOS_ELECTRON", TpFloat,
-		  "Average column density of electrons","m-2","");
-	// IONOS_ELECTRON_FLAG
-	colMapDef(IONOS_ELECTRON_FLAG, "IONOS_ELECTRON_FLAG", TpBool,
-		  "Flag for average column density of electrons","","");
-	// PRESSURE
-	colMapDef(PRESSURE, "PRESSURE", TpFloat,
-		  "Ambient atmospheric pressure","hPa","");
-	// PRESSURE_FLAG
-	colMapDef(PRESSURE_FLAG, "PRESSURE_FLAG", TpBool,
-		  "Flag for ambient atmospheric pressure","","");
-	// REL_HUMIDITY
-	colMapDef(REL_HUMIDITY, "REL_HUMIDITY", TpFloat,
-		  "Ambient relative humidity","%","");
-	// REL_HUMIDITY_FLAG
-	colMapDef(REL_HUMIDITY_FLAG, "REL_HUMIDITY_FLAG", TpBool,
-		  "Flag for ambient relative humidity","","");
-	// TEMPERATURE
-	colMapDef(TEMPERATURE, "TEMPERATURE", TpFloat,
-		  "Ambient Air Temperature for an antenna","K","");
-	// TEMPERATURE_FLAG
-	colMapDef(TEMPERATURE_FLAG, "TEMPERATURE_FLAG", TpBool,
-		  "Flag for ambient Air Temperature for an antenna","","");
-	// WIND_DIRECTION
-	colMapDef(WIND_DIRECTION, "WIND_DIRECTION", TpFloat,
-		  "Average wind direction","rad","");
-	// WIND_DIRECTION_FLAG
-	colMapDef(WIND_DIRECTION_FLAG, "WIND_DIRECTION_FLAG", TpBool,
-		  "Flag for wind direction","","");
-	// WIND_SPEED
-	colMapDef(WIND_SPEED, "WIND_SPEED", TpFloat,
-		  "Average wind speed","m/s","");
-	// WIND_SPEED_FLAG
-	colMapDef(WIND_SPEED_FLAG, "WIND_SPEED_FLAG", TpBool,
-		  "Flag for wind speed","","");
-	// PredefinedKeywords
+  MSTableMaps maps;
+  // the PredefinedColumns
+  // ANTENNA_ID
+  colMapDef(maps, ANTENNA_ID, "ANTENNA_ID", TpInt,
+            "Antenna number","","");
+  // INTERVAL
+  colMapDef(maps, INTERVAL, "INTERVAL", TpDouble,
+            "Interval over which data is relevant","s","");
+  // TIME
+  colMapDef(maps, TIME, "TIME", TpDouble,
+            "An MEpoch specifying the midpoint of the time for"
+            "which data is relevant","s","Epoch");
+  // DEW_POINT
+  colMapDef(maps, DEW_POINT, "DEW_POINT", TpFloat,
+            "Dew point","K","");
+  // DEW_POINT_FLAG
+  colMapDef(maps, DEW_POINT_FLAG, "DEW_POINT_FLAG", TpBool,
+            "Flag for dew point","","");
+  // H2O 
+  colMapDef(maps, H2O, "H2O", TpFloat,
+            "Average column density of water-vapor","m-2","");
+  // H2O_FLAG
+  colMapDef(maps, H2O_FLAG, "H2O_FLAG", TpBool,
+            "Flag for average column density of water-vapor","","");
+  // IONOS_ELECTRON
+  colMapDef(maps, IONOS_ELECTRON, "IONOS_ELECTRON", TpFloat,
+            "Average column density of electrons","m-2","");
+  // IONOS_ELECTRON_FLAG
+  colMapDef(maps, IONOS_ELECTRON_FLAG, "IONOS_ELECTRON_FLAG", TpBool,
+            "Flag for average column density of electrons","","");
+  // PRESSURE
+  colMapDef(maps, PRESSURE, "PRESSURE", TpFloat,
+            "Ambient atmospheric pressure","hPa","");
+  // PRESSURE_FLAG
+  colMapDef(maps, PRESSURE_FLAG, "PRESSURE_FLAG", TpBool,
+            "Flag for ambient atmospheric pressure","","");
+  // REL_HUMIDITY
+  colMapDef(maps, REL_HUMIDITY, "REL_HUMIDITY", TpFloat,
+            "Ambient relative humidity","%","");
+  // REL_HUMIDITY_FLAG
+  colMapDef(maps, REL_HUMIDITY_FLAG, "REL_HUMIDITY_FLAG", TpBool,
+            "Flag for ambient relative humidity","","");
+  // TEMPERATURE
+  colMapDef(maps, TEMPERATURE, "TEMPERATURE", TpFloat,
+            "Ambient Air Temperature for an antenna","K","");
+  // TEMPERATURE_FLAG
+  colMapDef(maps, TEMPERATURE_FLAG, "TEMPERATURE_FLAG", TpBool,
+            "Flag for ambient Air Temperature for an antenna","","");
+  // WIND_DIRECTION
+  colMapDef(maps, WIND_DIRECTION, "WIND_DIRECTION", TpFloat,
+            "Average wind direction","rad","");
+  // WIND_DIRECTION_FLAG
+  colMapDef(maps, WIND_DIRECTION_FLAG, "WIND_DIRECTION_FLAG", TpBool,
+            "Flag for wind direction","","");
+  // WIND_SPEED
+  colMapDef(maps, WIND_SPEED, "WIND_SPEED", TpFloat,
+            "Average wind speed","m/s","");
+  // WIND_SPEED_FLAG
+  colMapDef(maps, WIND_SPEED_FLAG, "WIND_SPEED_FLAG", TpBool,
+            "Flag for wind speed","","");
+  // PredefinedKeywords
 
-	// init requiredTableDesc
-	TableDesc requiredTD;
-	// all required keywords
-	uInt i;
-	for (i = UNDEFINED_KEYWORD+1;
-	     i <= NUMBER_PREDEFINED_KEYWORDS; i++) {
-	    addKeyToDesc(requiredTD, PredefinedKeywords(i));
-	}
-	
-	// all required columns 
-	for (i = UNDEFINED_COLUMN+1; 
-	     i <= NUMBER_REQUIRED_COLUMNS; i++) {
-	    addColumnToDesc(requiredTD, PredefinedColumns(i));
-	}
-	requiredTD_p=new TableDesc(requiredTD);
-    }
+  // init requiredTableDesc
+  // all required keywords
+  uInt i;
+  for (i = UNDEFINED_KEYWORD+1;
+       i <= NUMBER_PREDEFINED_KEYWORDS; i++) {
+    addKeyToDesc(maps, PredefinedKeywords(i));
+  }
+  // all required columns 
+  for (i = UNDEFINED_COLUMN+1; 
+       i <= NUMBER_REQUIRED_COLUMNS; i++) {
+    addColumnToDesc(maps, PredefinedColumns(i));
+  }
+
+  return maps;
 }
-	
+
 MSWeather MSWeather::referenceCopy(const String& newTableName, 
 				   const Block<String>& writableColumns) const
 {
-    return MSWeather(MSTable<PredefinedColumns,PredefinedKeywords>::
+    return MSWeather(MSTable<MSWeatherEnums>::
 		     referenceCopy(newTableName,writableColumns));
 }
 
