@@ -238,8 +238,7 @@ typedef MeasurementSet MS;
 //      be necessary to modify referenceCopy().
 // </todo>
 
-class MeasurementSet : public MSTable<MSMainEnums::PredefinedColumns,
-                                      MSMainEnums::PredefinedKeywords>,
+class MeasurementSet : public MSTable<MSMainEnums>,
 		       public MSMainEnums
 {
 
@@ -275,6 +274,14 @@ public:
   MeasurementSet (SetupNewTable &newTab, const TableLock& lockOptions,
 		  uInt nrrow = 0, Bool initialize = False);
   MeasurementSet (const Table &table, const MeasurementSet * otherMs = NULL);
+
+#ifdef HAVE_MPI
+  MeasurementSet (MPI_Comm comm, SetupNewTable &newTab, uInt nrrow = 0,
+		  Bool initialize = False);
+  MeasurementSet (MPI_Comm comm, SetupNewTable &newTab, const TableLock& lockOptions,
+		  uInt nrrow = 0, Bool initialize = False);
+#endif // HAVE_MPI
+
   MeasurementSet (const MeasurementSet &other);
   // </group>
 
@@ -379,11 +386,14 @@ public:
   // often have more things specified, like dimensions of arrays and
   // storage managers for the various columns.
   void createDefaultSubtables(Table::TableOption option=Table::Scratch);
+#ifdef HAVE_MPI
+  void createDefaultSubtables(MPI_Comm comm, Table::TableOption option=Table::Scratch);
+#endif // HAVE_MPI
 
   // Initialize the statics appropriately. This does not need to be
   // called by users, it is called by the implementation class
   // MSTableImpl.
-  static void init();
+  static MSTableMaps initMaps();
 
   // Create DATA column from existing FLOAT_DATA column. Noop if DATA already
   // exists or neither exists (returns False in that case).
@@ -442,6 +452,11 @@ private:
   // check that the MS is the latest version (2.0)
   void checkVersion();
 
+  // Creates subtables using an explicit MPI communicator (if MPI support
+  // is enabled)
+  template<typename T>
+  void createDefaultSubtables_impl(Table::TableOption option, T comm);
+
   // Opens a single subtable as memory resident (if permitted).
   template <typename Subtable>
   void
