@@ -54,7 +54,7 @@ uInt tColumnStatics()
     // ensure that the conversions are consistent
     uInt errCount = 0;
 
-    for (Int i=0;i<MS::NUMBER_PREDEFINED_COLUMNS;i++) {
+    for (Int i=1;i<MS::NUMBER_PREDEFINED_COLUMNS;i++) {
 	MS::PredefinedColumns pdcol = MS::PredefinedColumns(i);
 	MS::columnDataType(pdcol);
 	String pdname = MS::columnName(pdcol);
@@ -94,7 +94,7 @@ uInt tKeywordStatics()
 
     // MS::PredefinedKeywords
 
-    for (uInt i=0;i<MS::NUMBER_PREDEFINED_KEYWORDS;i++) {
+    for (uInt i=1;i<MS::NUMBER_PREDEFINED_KEYWORDS;i++) {
 	MS::PredefinedKeywords pdkey = MS::PredefinedKeywords(i);
 	String pdname = MS::keywordName(pdkey);
 	MS::PredefinedKeywords pdtype = MS::keywordType(pdname);
@@ -191,10 +191,12 @@ uInt tNonStatic(const String& sdmsName)
     ms.createDefaultSubtables(Table::New);
 
     ArrayColumn<Float> fldata(ms,MS::columnName(MS::FLOAT_DATA));
+    ScalarColumn<Bool> flrow(ms,MS::columnName(MS::FLAG_ROW));
     for (Int i=0; i<10; i++) {
       Matrix<Float> arr(4,2);
       arr=Float(i);
       fldata.put(i,arr);
+      flrow.put(i,False);
     }
     
 
@@ -314,7 +316,7 @@ uInt tConstructors(const String& msName)
     Bool thrown=False;
     try {
 	MeasurementSet badms("tMeasurementSet_tmp.badmsTable");
-    } catch (AipsError x) {
+    } catch (AipsError& x) {
 	thrown = True;
     } 
     if (!thrown) errCount++;
@@ -325,7 +327,7 @@ uInt tConstructors(const String& msName)
     thrown=False;
     try {
 	MeasurementSet badms("tMeasurementSet_tmp.badmsTable","");
-    } catch (AipsError x) {
+    } catch (AipsError& x) {
 	thrown = True;
     } 
     if (!thrown) errCount++;
@@ -340,7 +342,7 @@ uInt tConstructors(const String& msName)
     try {
 	Table badtab("tMeasurementSet_tmp.badmsTab;e","");
 	MeasurementSet badms(badtab);
-    } catch (AipsError x) {
+    } catch (AipsError& x) {
 	thrown = True;
     } 
     if (!thrown) errCount++;
@@ -377,7 +379,7 @@ uInt tConstructors(const String& msName)
 	try {
 	    MSAntenna msant2b("tMeasurementSet_tmp.msant2","badAntTD",Table::Old);
 	    msant2b.markForDelete();
-	} catch (AipsError x) {
+	} catch (AipsError& x) {
 	    thrown = True;
 	} 
 	// No exception is thrown here, even though the td name is wrong..
@@ -395,7 +397,7 @@ uInt tConstructors(const String& msName)
 	    SetupNewTable newtab("tMeasurementSet_tmp.msant3b",
 				 MSFeed::requiredTableDesc(),Table::New);
 	    MSAntenna msant3b(newtab,5);
-	} catch (AipsError x) {
+	} catch (AipsError& x) {
 	    thrown = True;
 	} 
 	if (!thrown) errCount++;
@@ -423,7 +425,7 @@ uInt tConstructors(const String& msName)
 	    Table tab(newtab4);
 	    tab.markForDelete();
 	    MSAntenna msant4b(tab);
-	} catch (AipsError x) {
+	} catch (AipsError& x) {
 	    thrown = True;
 	} 
 	if (!thrown) errCount++;
@@ -438,7 +440,7 @@ uInt tConstructors(const String& msName)
 		Table tab("tMeasurementSet_tmp.badmsantTable","badAntTD",Table::New);
 	    }
 	    MSAntenna msant5b("tMeasurementSet_tmp.badmsantTable");
-	} catch (AipsError x) {
+	} catch (AipsError& x) {
 	    thrown = True;
 	} 
 	if (!thrown) errCount++;
@@ -451,7 +453,7 @@ uInt tConstructors(const String& msName)
 	    MSFeed msfeed("msfeed", Table::New);
 	    msfeed.markForDelete();
 	    MSAntenna msant6b(msfeed);
-	} catch (AipsError x) {
+	} catch (AipsError& x) {
 	    thrown = True;
 	} 
 	if (!thrown) errCount++;
@@ -521,7 +523,7 @@ uInt tSetupNewTabError()
     Bool thrown = False;
     try {
 	MeasurementSet ms(setup,0);
-    } catch (AipsError x) {
+    } catch (AipsError& x) {
 	thrown = True;
     } 
     if (!thrown) {
@@ -542,7 +544,7 @@ uInt tDestructorError(const String& sdmsName)
 	MeasurementSet ms(sdmsName);
 	// remove a column
 	ms.removeColumn(MS::columnName(MS::TIME));
-    } catch (AipsError x) {
+    } catch (AipsError& x) {
 	thrown = True;
     } 
 
@@ -626,7 +628,7 @@ int main() {
     }
 
     return errCount;
-  } catch (AipsError x) {
+  } catch (AipsError& x) {
       cerr << x.getMesg() << endl;
   } 
   return 1;
