@@ -1197,7 +1197,7 @@ int main() {
     }
     
     cout << "---------------------------------------------------" << endl;
-  } catch (AipsError x) {
+  } catch (AipsError& x) {
     cout << x.getMesg() << endl;
   }
   return 0;
