@@ -2304,7 +2304,7 @@ int main()
       run_tests<Double, DComplex>();
 
   }
-  catch (AipsError x) {
+  catch (AipsError& x) {
     cerr << x.getMesg() << endl;
     cout << "FAIL" << endl;
     return 1;
