@@ -103,14 +103,14 @@ public:
     // Optionally the end is inclusive (C++ and Glish style) or exclusive
     // (Python style).
     TableExprNodeSetElem (const TableExprNode* start,
-			  const TableExprNode* end,
-			  const TableExprNode* incr,
-			  Bool isEndExcl = False);
+                          const TableExprNode* end,
+                          const TableExprNode* incr,
+                          Bool isEndExcl = False);
 
     // Create the object for a continuous bounded interval. It can be
     // open or closed on either side.
     TableExprNodeSetElem (Bool isLeftClosed, const TableExprNode& start,
-			  const TableExprNode& end, Bool isRightClosed);
+                          const TableExprNode& end, Bool isRightClosed);
 
     // Create the object for a continuous left-bounded interval.
     TableExprNodeSetElem (Bool isLeftClosed, const TableExprNode& start);
@@ -165,11 +165,11 @@ public:
     void fillVector (Vector<Double>& vec, Int64& cnt,
                      const TableExprId& id) const;
     void fillVector (Vector<DComplex>& vec, Int64& cnt,
-		     const TableExprId& id) const;
+                     const TableExprId& id) const;
     void fillVector (Vector<String>& vec, Int64& cnt,
-		     const TableExprId& id) const;
+                     const TableExprId& id) const;
     void fillVector (Vector<MVTime>& vec, Int64& cnt,
-		     const TableExprId& id) const;
+                     const TableExprId& id) const;
     // </group>
 
     // Set a flag in the match output array if the corresponding element
@@ -179,17 +179,17 @@ public:
     // are initialized that way.
     // <group>
     void matchBool     (Bool* match, const Bool* value, uInt nval,
-			const TableExprId& id) const;
+                        const TableExprId& id) const;
     void matchInt      (Bool* match, const Int64* value, uInt nval,
-			const TableExprId& id) const;
+                        const TableExprId& id) const;
     void matchDouble   (Bool* match, const Double* value, uInt nval,
-			const TableExprId& id) const;
+                        const TableExprId& id) const;
     void matchDComplex (Bool* match, const DComplex* value, uInt nval,
-			const TableExprId& id) const;
+                        const TableExprId& id) const;
     void matchString   (Bool* match, const String* value, uInt nval,
-			const TableExprId& id) const;
+                        const TableExprId& id) const;
     void matchDate     (Bool* match, const MVTime* value, uInt nval,
-			const TableExprId& id) const;
+                        const TableExprId& id) const;
     // </group>
 
     // Evaluate the element for the given row and construct a new
@@ -210,12 +210,12 @@ private:
     // Construct an element from the given parts and take over their pointers.
     // It is used by evaluate to construct an element in a rather cheap way.
     TableExprNodeSetElem (const TableExprNodeSetElem& that,
-			  const TENShPtr& start, const TENShPtr& end,
-			  const TENShPtr& incr);
+                          const TENShPtr& start, const TENShPtr& end,
+                          const TENShPtr& incr);
 
     // Setup the object for a continuous interval.
     void setup (Bool isLeftClosed, const TableExprNode* start,
-		const TableExprNode* end, Bool isRightClosed);
+                const TableExprNode* end, Bool isRightClosed);
 
 
     TENShPtr itsStart;
@@ -507,25 +507,31 @@ inline const TableExprNodeSetElem&
 template<typename T>
 MArray<T> TableExprNodeSet::toArray (const TableExprId& id) const
 {
-  // TODO: align possible units
+  /// TODO: align possible units
     DebugAssert (itsBounded, AipsError);
     Int64 n = size();
     if (hasArrays()) {
       // Handle a nested array; this is done recursively.
       MArray<T> marr;
       getArray (marr, castItsElem(0)->start(), id);
-      if (marr.isNull()) return marr;
+      if (marr.isNull()) {
+        return marr;
+      }
       Array<T> result (marr.array());
       Array<Bool> mask (marr.mask());
       IPosition shp = result.shape();
       uInt naxes = shp.size();
       shp.append (IPosition(1,n));
+      IPosition maskShp(shp);
+      maskShp[maskShp.size()-1] = 1;
       result.resize (shp, True);
-      if (! mask.empty()) mask.resize (shp, True);
+      if (! mask.empty()) {
+        mask.resize (shp, True);
+      }
+      // Iterate through the remaining arrays.
       ArrayIterator<T> iter(result, shp.size()-1);
-      IPosition s(shp);
-      IPosition e(shp);
-      s[naxes] = 0;
+      IPosition s(shp.size(), 0);
+      IPosition e(shp-1);
       e[naxes] = 0;
       for (Int64 i=1; i<n; i++) {
         iter.next();
@@ -533,23 +539,28 @@ MArray<T> TableExprNodeSet::toArray (const TableExprId& id) const
         e[naxes]++;
         MArray<T> marr;
         getArray (marr, castItsElem(i)->start(), id);
-        if (marr.isNull()) return marr;
+        if (marr.isNull()) {
+          return marr;
+        }
         if (! marr.shape().isEqual (iter.array().shape())) {
           throw TableInvExpr("Shapes of nested arrays do not match");
         }
         iter.array() = marr.array();
         if (marr.hasMask()) {
           if (mask.empty()) {
+            // The first time a mask was found, so create the resulting mask.
             mask.resize (shp);
             mask = False;
           }
-          mask(s,e) = marr.mask();
+          mask(s,e) = marr.mask().reform(maskShp);
         } else if (! mask.empty()) {
+          // This array has no mask, so set to False in resulting mask.
           mask(s,e) = False;
         }
       }
       return MArray<T>(result, mask);
     } else {
+      // Combine scalars.
       Int64 n = size();
       Int64 cnt = 0;
       Vector<T> result (n);
