@@ -186,7 +186,7 @@ void doIt()
     Bool err = False;
     try {
       TableExprNode expr8 (RecordGram::parse (rec, "rownumber() > 3"));
-    } catch (AipsError x) {
+    } catch (AipsError& x) {
       cout << "Expected exception:\n" << x.getMesg() << endl;
       err = True;
     }
@@ -266,7 +266,7 @@ int main()
   try {
     doIt();
     testExpr2();
-  } catch (AipsError x) {
+  } catch (AipsError& x) {
     cout << "Unexpected exception: " << x.getMesg() << endl;
     return 1;
   } catch (...) {
