@@ -129,6 +129,11 @@ void ColumnsIndex::deleteObjects()
       delete (RecordFieldPtr<uInt>*)(itsUpperFields[i]);
       delete (Vector<uInt>*)(itsDataVectors[i]);
       break;
+    case TpInt64:
+      delete (RecordFieldPtr<Int64>*)(itsLowerFields[i]);
+      delete (RecordFieldPtr<Int64>*)(itsUpperFields[i]);
+      delete (Vector<Int64>*)(itsDataVectors[i]);
+      break;
     case TpFloat:
       delete (RecordFieldPtr<Float>*)(itsLowerFields[i]);
       delete (RecordFieldPtr<Float>*)(itsUpperFields[i]);
@@ -261,6 +266,13 @@ void ColumnsIndex::makeObjects (const RecordDesc& description)
       itsDataVectors[i] = new Vector<uInt>;
       break;
     }
+    case TpInt64:
+    {
+      itsLowerFields[i] = new RecordFieldPtr<Int64>(*itsLowerKeyPtr, i);
+      itsUpperFields[i] = new RecordFieldPtr<Int64>(*itsUpperKeyPtr, i);
+      itsDataVectors[i] = new Vector<Int64>;
+      break;
+    }
     case TpFloat:
     {
       itsLowerFields[i] = new RecordFieldPtr<Float>(*itsLowerKeyPtr, i);
@@ -372,6 +384,16 @@ void ColumnsIndex::readData()
       sort.sortKey (itsData[i], desc.type(i));
       break;
     }
+    case TpInt64:
+    {
+      Vector<Int64>* vecptr = (Vector<Int64>*)itsDataVectors[i];
+      if (itsColumnChanged[i]) {
+	ScalarColumn<Int64>(itsTable, name).getColumn (*vecptr, True);
+      }
+      itsData[i] = vecptr->getStorage (deleteIt);
+      sort.sortKey (itsData[i], desc.type(i));
+      break;
+    }
     case TpFloat:
     {
       Vector<Float>* vecptr = (Vector<Float>*)itsDataVectors[i];
@@ -529,6 +551,17 @@ Int ColumnsIndex::compare (const Block<void*>& fieldPtrs,
       }
       break;
     }
+    case TpInt64:
+    {
+      const Int64 left = *(*(RecordFieldPtr<Int64>*)(fieldPtrs[i]));
+      const Int64 right = ((const Int64*)(dataPtrs[i]))[index];
+      if (left < right) {
+	return -1;
+      } else if (left > right) {
+	return 1;
+      }
+      break;
+    }
     case TpFloat:
     {
       const Float left = *(*(RecordFieldPtr<Float>*)(fieldPtrs[i]));
@@ -722,6 +755,9 @@ void ColumnsIndex::copyKeyField (void* fieldPtr, int dtype, const Record& key)
     case TpUInt:
       copyKeyField(*(RecordFieldPtr<uInt>*)(fieldPtr), key);
       break;
+    case TpInt64:
+      copyKeyField(*(RecordFieldPtr<Int64>*)(fieldPtr), key);
+      break;
     case TpFloat:
       copyKeyField(*(RecordFieldPtr<Float>*)(fieldPtr), key);
       break;
